@@ -112,8 +112,15 @@ def exists(path: str) -> bool:
     return has_keys
 
 
-def generate_path(suffix: str, prefix: Optional[str] = os.environ.get('DATA_PATH', None)) -> str:
-    return os.path.join(prefix, suffix) if prefix else os.path.join(tempfile.gettempdir(), suffix)
+def generate_path(suffix: Optional[str] = None, prefix: Optional[str] = os.environ.get('DATA_PATH', None)) -> str:
+    prefix = prefix if prefix else tempfile.gettempdir()
+
+    if not suffix:
+        return prefix
+
+    path = os.path.join(prefix, suffix)
+
+    return path
 
 
 def localize_directory(
@@ -140,15 +147,7 @@ def localize_directory(
     for key in _get_s3_keys(bucket, key_base_prefixed):
         download_s3(bucket, key, generate_path(os.path.relpath(key, key_base), directory))
 
-    return directory_prefixed
-
-
-def localize_directory_prefixed(path: str, directory: Optional[str] = None, overwrite: bool = True) -> str:
-    path, prefix = os.path.split(path)
-
-    local_path_prefixed = localize_directory(path, directory, prefix, overwrite)
-
-    return local_path_prefixed
+    return directory
 
 
 def localize_file(path: str, overwrite: bool = True) -> str:
